---
title: "Book Review: Capital as Power"
---

# Part A: Overview

## 1. Motivation

If you are a well-educated person in the 21st century, you probably have conflicted views. On the one hand, the grand socialist project has had... problems... over the last century. Serious problems. Problems that kill and hurt people, and are really, really non-dismissable. For a bibliography, check [here](https://www.independent.org/issues/article.asp?id=13056).

On the other hand, the (main) alternative is capitalism. And that also sucks. A lot. If you haven't noticed this, you haven't been paying attention.

*Capital as Power* by Bichler and Nitzan does not even attempt to talk about an alternative system of government. However, it argues that a necessary precondition for radical system change is a new theory of economics. In their words:

> Perhaps the key problem facing young people today is a lack of theoretical alternatives. A new social reality presupposes and implies a new social cosmology. To change the capitalist world, one first needs to re-conceive it; and that re-conception means new ways of thinking, new categories and new measurements. And yet, many contemporary critics of capitalism seem to believe that they can challenge this social order without ever asking how it operates, let alone why.

<span style="color:red">
(picture of a young person facing problems)
</span>

The purpose of Capital as Power is to provide such a theoretical alternative. However such a thing is easier said than done. To start with, it is necessary to give a thorough examination of past attempts to put economics on sound theoretical feet. Bichler and Nitzan provide some blistering polemic towards those who try to build the future without understanding this, that I could not help but include.

> With some obvious exceptions, present-day leftists prefer to avoid ‘the economy’, and many are rather proud about it. To prioritize profit and accumulation, to theorize corporations and the stock market, to empirically research the gyrations of money and prices are all acts of narrow ‘economism’. To do these things is to fetishize the world, to conceal the cultural nuances of human consciousness, to prevent the critic from seeing the true political underpinnings of social affairs. Best to leave them to the dismal scientists.
>
> And, so, most self-respecting critics of capitalism remain happily ignorant of its ‘economics’, neoclassical as well as Marxist. They know little about the respective histories, questions and challenges of these theories, and they are oblivious to their triumphs, contradictions and failures. This innocence is certainly liberating. It allows critics to produce ‘critical discourse’ littered with cut-and-paste platitudes, ambiguities and often plain nonsense. Seldom do their ‘critiques’ tell us something important about the forces of contemporary capitalism, let alone about how these forces should be researched, understood and challenged.

Concordant with the spirit of this last paragraph, Bichler and Nitzan devote much of the first half of the book to a critical dive into the history over the last two centuries of the "dismal science", both Marxist and Neoclassical.

## 2. Theories of Value

I learned a *lot* about both neoliberalism and Marxism, and this part of the book would hold up as a good survey, even without the arguments they make for why the theories ultimately fail.

It centers the analysis on an idea that both neoliberalism and Marxism are ultimately tied to *theories of value*. We are familiar with the neoliberal theory of value to such an extent that it is hard to even realize it is a theory. The neoliberal theory of value is that value comes from the utility that a good delivers to its consumer. Often this is how economics textbooks start, and they promise that the arguments that you can think of off the top of your head against this model have good counter-arguments, and in any case it's a useful model. Students with further questions are told that real economists use better theories than this, but they are too complicated to put in introductory textbooks.[^1] Bichler and Nitzan do a thorough job expounding on arguments that an intro econ student might think of, but could not come close to articulating in enough detail to make headway.

The Marxist theory of value is that value comes from the work that humans put into material goods. On the face of it, this makes a lot of sense. Ultimately, the limiting factor to production comes down to humans: no humans = no production. However, this theory also has holes in it.

The key to Bichler and Nitzan's arguments against both theories is that they cannot explain how capital accumulates, or provide a framework in which predictions about value can be made. This was refreshing; I'm used to moral denunciations of capitalism, but denunciation of neoliberal economics as a theory with poor explanatory power is really out of left field.

[^1]: And in fact real economists do have better theories, namely behavioral economics. In my recollection, Bichler and Nitzan don't address behavioral economics within Capital as Power, and as I am not an economist, I can't say how valid their critiques of neoliberal economics are. *shrug*

## 3. Business and Industry

After thoroughly examining the Marxist and Neoliberal concepts of value, Capital as Power then moves into a discussion of the theories of someone I had never heard about, a man named Thorstein Veblen. According to Wikipedia, Veblen coined the term "conspicuous consumption", so he's someone that you've been influenced by, even if you haven't heard of him. But the most compelling coinage that Veblen makes, in my mind, is that there is a fundamental distinction between Business and Industry. Industry is the domain of the kind of people who build giant redstone contraptions in Minecraft or the kind of people who name their lab mice and talk to them in squeeky voices while cleaning up after an experiment that went on until 1am. It is both a collaborative activity and a competetive activity, but it is fundamentally built on creativity, curiousity and a desire to solve problems. Business is the domain of the kind of people who network at parties and care a lot about "corporate strategy". The point of Business is profit and accumulation.

<span style="color:red">
(a picture of a disheveled scientist talking to her rats at 1am)
</span>

From a Marxist standpoint, Business exploits Industry. Therefore, from a moral perspective, Business is Bad. From a neoliberal standpoint, Business provides the necessary resources and incentives for industry. Therefore, from a practical standpoint, Business is Good. To me, it seems like *both* of these analyses are taken for granted in my sphere of discourse. That is, business is seen as a necessary evil. Another way of saying this is that Business provides the necessary incentive structure for Industry.

Veblen has a hot take, which is that Business fundamentally needs to restrict Industry to make profits.

> Now the critical bit here is that industry and business are inherently distinct. Modern capitalists are removed from production: they are absentee owners. Their ownership, says Veblen, doesn’t contribute to industry; it merely controls it for profitable ends. And since the owners are absent from industry, the only way for them to exact their profit is by ‘sabotaging’ industry.

The *one thing* capitalism was supposed to be good at was high-quality goods at low prices, this is the promise dangled from the hands of every billboard in Times Square and every dense 800-page neoliberal economics book. But actually, business subverts the production of quality goods at low prices for the purpose of profit.

The question then becomes, if efficient production of goods and services, the raison d'être of the existence of the firm in the neoliberal world, is actually in opposition with the interests of Business, what is the true spring from which the C-suite's schemes are sprung?

## 4. Accumulation of Power

Bichler and Nitzan take another deep dive here, this time into the ideas of a theorist by the name of Lewis Mumford. Mumford takes us back all the way to the beginning of what we now call civilization, in the Nile River delta. His conceit is that the first "technology" was not mechanical or chemical, it was social. The organizational structure of ancient Egypt, with its intricate hierarchy of politics and religion meshed together, was a form of power previously unmatched in its ability to change its surroundings and to persist through time.

And here I add my own analysis from a historian who I doubt Bichler and Nitzan have heard of, though that does not diminish her in the slightest: my ninth grade history teacher, Audrey Budding. In that class, it was impressed on me thoroughly that one of the most common threads through history and one of the most important questions to ask about a society is how legitimacy of the ruling class is acheived.

In this lens, the novel technology of Egypt was the ability to give its rulers, through religion, tradition, force, and bureaucracy, enough legitimacy that they could impress their will through a massive population.

<span style="color:red">
(picture of legitimizing rule through Egyptian iconography; a collage of oppressed peasants, hieroglyphics, and pyramids)
</span>

Mumford calls this new technology the "mega-machine", and Bichler and Nitzan take an interesting romp through some of the mega-machine's greatist hits throughout the years since the fall of Egypt.

According to them, the most recent incarnation of the mega-machine is the entirely novel *quantification of power through capital*. With the dazzling mathematics of the market, the mega-machine has reached heights of sophistication that the gold-plated pharoahs of yester-millenium could only dream of. The mechanism by which the ruling class exerts power is tightly woven into the daily fabric of the lives of their thralls, and legitimized by every interaction that becomes a transaction.

At this point, you are probably thinking "Yes! This is the hot tea that I signed up for when I clicked on a link that claimed to lead to a book review of a book called Capital as Power!"

I hate to disappoint you, but this is the end of the introduction, and we're not going to get back to the real juicy stuff until after about a thousand or so words droning on about theories of value and dead white men.

You see, I'm trying to give you a picture of what it is like to read "Capital as Power", and the experience of having a tantalizing insight dangled in front of you but then being forced to read far more history and statistics than you would really like to get there is truly an integral part of that book.

# Part B: Dilemmas of the Dismal Science

## 1. Politics and Economy

Before the industrial revolution, one could make a decent argument that political power and economic power could be separated to some extent. One strong point in favor was the separation of nobles, merchants, and clergy. Certainly, nobles often happened to be rich, but their wealth mostly derived from land-ownership, and their political power was mainly derived from their birth and connections, rather than their wealth (though, connections and wealth could go hand and hand). Merchants, even though they could have influence through their wealth, were excluded from positions of political power. And the clergy, in some cases more important than the nobles or the politicians, were also quite separated from both.

<span style="color:red">
(picture of medieval nobles and merchants)
</span>

It is from this situation that the "original sin" of economics derives: the belief that economics is productively analyzed outside of political context. The original liberals relied on this duality to expound on their idea that the ideal government simply facilitates the movements of the market.

Marx was the first to question this belief, claiming that it was only through political oppression that industrialists were able to acheive their economic exploitation. However, he still makes an essential distinction between the two, and the Marxist viewpoint is that the contradictions between the political and economic spheres are what will eventually bring down capitalism and usher in communism, where politics and economics will finally be united.

Bichler and Nitzan take as a jumping-off point this faulty duality, and use it to explain how various problems come up in both theories. For instance, the pure "Newtonian" laws of microeconomics were eventually forced to be revised by the Great Depression, and the new science of "macroeconomics" was introduced to account for this. Since then, the systematic differences of the real world from the "spontaneous equilibrium" of the market have been accounted for by an ever growing pageant of "distortions", applied ad-hoc. But just as Ptolemaic astronomy eventually drowned under the weight of its many epicycles, so is neoclassical economics struggling under the weight of all of the various compensations needed to account for politics in a theory that assumes politics is out of the picture.

In Marxism, a similar problem arose as the competition-rich environment where Marx original made his theories gave way to a new monopolistic capitalism. Without competition, the tendency of prices of goods to correlate with the prices of labor, and for profits to equalize among different sectors no longer held true. To account for this, Neo-Marxists developed a new theory that attempted to bring power back into the picture. However, like the man who cannot light his cigarette without putting down his teacup, in order to do so the labor theory of value had to be jettisoned, and Neo-Marxism became unmoored from the theoretical framework that birthed it. When the stagflation of the 70s and 80s hit along with the breakup of "state capitalism", Neo-Marxism ceased to be an accurate description of the world, and leftists attempted to move back to original Marxism, decrying the period of monopoly as a "historical blip". However, there was little left of the original theory that still made sense, and many Marxists moved to cultural critiques, abandoning the original attempt of Marxism to put the study of capitalism on a scientific basis.

## 2. The Nominal and The Material

Another issue that plagues both Marxist and neoliberal analyses is an attempt to make a distinction between what I might call "the map" and the "territory." On the Marxist side, this comes up as a distinction between "fictional" and "real" capital. "Real" capital is owned by industrial capitalists, who employ productive labor to create surplus value. I imagine that Marx was thinking of factories here. "Fictional" capital, on the other hand, is capital owned by commercial and financial capitalists, who merely appropriate the value generated by productive labor. Intuitively, this is theory that one is inclined to be sympathetic to. On the one hand, you have farmers and laborers, who are clearly producing surplus, and on the other hand you have stock brokers, who clearly are just siphoning off the top. But to actually give a sturdy definition of what is "productive" and what is "unproductive" is not at all easy.

<span style="color:red">
(picture of stonks)
</span>

On the other hand, the liberals face a similar dilemna as they argue that the market ultimately represents the movements of actual industrial processes. Bichler and Nitzan argue that liberals were originally motivated to do this in order to make the argument that, unlike nobles who acquired their wealth by looting or birth, the new rich acquired their money by work. If ultimately the market is just a representation of real processes that bring material changes in the world, then business deals are as legitimate a form of work as manufacturing and farming, and so just as the laborer is entitled to the work brought in by the sweat of his brow, so is the businessman entitled to whatever rewards he can manage to make by fair participation in the market.

However, this has its own problems. The movements of capital markets are empirically quite difficult to correlate with the movements of the underlying material assets that those markets are supposed to represent. Again, neoliberals employ a pageant of epicycles to explain away this, but there are only so many epicycles that a scientist should accept.

## 3. What is Value?

I start this section with a direct quote from Bichler and Nitzan

> To study the rationalist order of capitalism without quantities is like studying feudalism without religion, or physics without mathematics. According to Marx, and here he was right on the mark, capitalism, by its very nature, seeks to turn quality into quantity, to objectify and reify social relations as if they were natural and unassailable. In this sense, a qualitative theory of value necessarily implies a quantitative theory of value; it means a society not only obsessed with numbers, but actually shaped and organized by numbers. This organization is the architecture of capitalist power. To understand capitalism therefore is to decipher the link between quality and quantity, to reduce the multifaceted nature of social power to the universal appearance of capital accumulation. The two aspects of the theory rise and fall together. If one is proven wrong, so is the other.

With this passage, Bichler and Nitzan set a high bar for theories. It is not enough for a theory of capitalism to give a qualitative account of value because the nature of capitalism is quantitative. It is on this cross of numerics that the Marxist "abstract labor" and the neoclassicist "util" are ultimately crucified.

They lay the problem out in the following way. It is well understood that wealth is not well-measured by current market value, because of inflation. Economists get around this by coming up with a "price index", which measures how much a "standard bundle" of goods and services would cost at different times. By this mechanism, comparisons of value across time can be measured. However, the definition of such a "standard bundle" is highly problematic. If this standard bundle were, say, a single transistor, then an economist would conclude that we are over a million times richer than we were in the 1960s. This is clearly not true. Of course, an economist would not calculate a price index in this way, but almost any commodity has similar problems, though less extreme, from roast passenger pigeon to steel.

<span style="color:red">
(An illustration of a fictional "standard bundle of goods")
</span>

In practice, some reasonable judgement is made on which commodities to include. But on what basis is this judgement made? The theoretical underpinnings of neoclassicism are that things are ultimately denominated in "utils". This explains why we don't simply multiply by the number of transistors: utils don't scale linearly with the number of transistors. This explains why roast passenger pigeon would go for a high price now; it's scarcity would cause someone to derive great utility from their signaling of wealth by eating it, or great utility from their curiousity in how it tastes.

As a qualitative theory, utils certainly have a lot going for them. I buy groceries because I derive utility from eating them. I pay rent because I derive utility from having a roof over my head. But even the most ardent proponents of the new utilitarianism balked at doing actual calculations.

> In fact, they admitted quite openly that universal utility is impossible to measure and, indeed, difficult to even fathom. The interesting thing, though, is that this recognition did not deter them in the least. 'If you cannot measure, measure anyhow,' complained their in-house critic Frank Knight

Instead, neoliberal economists developed a theory of "revealed preferences." This theory says the following:

> ‘*Utility* is the quality in commodities that makes individuals want to buy them, and the fact that individuals want to buy commodities shows that they have *utility*’ (Robinson 1962: 48, emphases original to Bichler and Nitzan).

We wanted to compare wealth over time. Prices change due to inflation, technological improvements, and a whole host of other things, so we need a theory of value that allows us to make this comparison. Utility provides that theory of value. How do we measure utility? Prices. Whoops...

I want to make it explicit that Bichler and Nitzan aren't making the argument that utilitarianism is not a good basis for morality. This kind of argument would not be novel or relevant. They are making the argument that utilitarianism is a bad basis for a theory of capitalism because it fails to make quantitative testable predictions.

While I'm clarifying things, I might as well reiterate (though it should go without saying) that anyone wishing to refute any of the arguments that I set out here, should not take my presentation as canonical in any way; Bichler and Nitzan's arguments are far more comprehensive than my brief summary. Although I promised that I would bore you with history and statistics, I really don't have the space or time.

A similar circularity happens with the labor theory of value. I won't go into as much detail, because I think it's somewhat widely accepted that the labor theory of value doesn't really work, but I encourage the interested reader to read the relevant parts in "Capital as Power"; I learned a lot about what the labor theory of value actually means that I had never really had explained to me in such detail.

# Part C: The Machine

<span style="color:red">
(a Howl-esque picture of the machine)
</span>

## 1. Internal vs. External Logic

If we cannot use utility or abstract labor, then by what means can we determine value? Bichler and Nitzan do not have an answer to this question. They instead say that it is the wrong question to ask. It makes no sense to try to anchor the fluctuating numbers of human society to some fixed and eternal quantity. Rather, prices are just another expression of society.

> According to Cornelius Castoriadis (1984), this alternative was articulated some 2,500 years ago, by Aristotle. Equivalence in exchange, Aristotle argued, came not from anything intrinsic to commodities, but from what the Greek called the nomos. It was rooted not in the material sphere of consumption and production, but in the broader social–legal–historical institutions of society. It was not an objective substance, but a human creation.

This articulates the idea that capitalism exists on a continuum. The idea that a gift economy or dictatorship is based on societal context is totally uncontroversial; why should the theory of a transactional economy be any different?

> Consider the ratio between the price of petroleum and the wages of oil rig workers; between the value of Enron’s assets and the salaries of accountants; between General Electric’s rate of profit and the price of jet engines; between Halliburton’s earnings and the cost of ‘re-building’ Iraq; between Viacom’s taxes and advertisement rates; between the market capitalization of sub-prime lenders and government bailouts. Why insist that these ratios are somehow determined by — or deviate from — relative utility or relative abstract labour time? Why anchor the logic of capitalism in quanta that cannot be shown to exist, and that no one — not even those who need to know them in order to set prices — has the slightest idea what they are? Isn’t it possible that these capitalist ratios are simply the outcome of social struggles and cooperation?

The title of this section comes from my personal spin on this. Euclid tried to define all of the geometrical terms that he worked with rigorously. However, such an attempt was inevitably circular. Modern mathematics affirms that the proper way to axiomatize math is to start with undefined terms, which derive meaning through their relation to each other. That is, ultimately mathematics cannot be given an "external" grounding; it must be defined through "internal" means.

This is also well-understood in the linguistic sphere. An objective definition of a word does not exist; all that exists is the totality of that words relationship with actions and with other words.

So it makes sense that prices and capital and markets are not objectively defined quantities, but exist only in relation to the larger context of civilization.

This resolves the dilemnas of part B. Politics and economics are clearly not separated; the study of one is the study of the other. The private ownership of "financial" assets is just as "real" as the private ownership of material goods; they are simply relations that exist in a certain societal context. And finally, there is no objective standard of value.

But wait, you are surely thinking, isn't this giving up? After crucifying neoliberal and Marxist theories on a cross of numerics, it's a pretty poor showing to have the theory that's supposed to replace them be all "societally-determined" woo.

The answer is that productive empirical tests and theories can be produced from this mindset. Abandoning an "external logic" of capitalism does not mean that scientific inquiry has to pack up and go home. Rather, it frees us to look for theories that are embedded in specific contexts and divorced from pretensions of universality.

An analogy can be drawn here to machine translation: the "rules-based" systems of the early AI days are no match for the deep learning systems of today, and the transition was predicated on an understanding that the meaning of a word can't be pinned down with formal rules (and of course also predicated on GPUs).

Interestingly enough, I believe that this mindset allows us to salvage a great deal of neoliberal and Marxist economics. When properly contextualized and removed from their moral and theoretical underpinnings, these theories can have great empirical success.

The famous physicist and captain of the high seas Robert Hooke believed that the law that he discovered governing the motion of a spring, $\ddot{x} = -kx$, where $x$ is the displacement from rest position, was a new law of nature. However, it actually turned out to just be a good approximation in certain cases, and we still use Hooke's law in engineering because of this.

<span style="color:red">
(illustration of Robert Hooke)
</span>

I think that many economists are all too aware that they are just using an approximation. And if I wanted to know the answer to a given question, I would look to expert economic judgement. This is because a highly tuned misguided theory often gives much better results than a poorly tuned well-founded theory. I recently bought a subscription to the Economist, and despite its heavy neoliberal bias, I still think it gives a clearer picture of the world than many other news sources; a large helping of meritocracy goes a long way. However, the way that human brains work is that understanding is layered. After working with principles and laws for a long time, we forget what the underlying assumptions that lead us to come up with those principles and laws were, and are therefore less able to ascertain when those principles and laws no longer hold.

In this way, implicit assumptions about the nature of economics radically change the type of models that are even considered, and also radically change political views. Therefore, although this indictment of neoliberal theory does not in my mind invalidate expert scientific consensus in many areas, it does undermine *political* arguments based on neoliberal/Marxist theory, and it opens the door to new scientific ideas. And both of these are needed if this new theory is to be a success; to make a dent in neoliberal consensus where "cultural" theories have failed it must open up previously poorly understood areas to empirical analysis, and to better guide society it must have political implications based on that new empirical analysis.

## 2. Capital and Capitalization

In the previous section, we moved a bit far afield from the review. We now move back to the book as it attempts to examine the "internal logic" of capitalism; the processes and beliefs that keep it afloat.

Bichler and Nitzan argue that the central process of capitalism is, fittingly, *capitalization*. Capitilization is the process of taking an asset that is expected produce a certain stream of future profits and assigning a current price to it. This is acheived through a *discount rate*, where future profits are valued lower than present profits. That is, we assume that 1 dollar now is worth the same as $d$ dollars in a year. Mathematically, we can then say that if the profit from an asset $n$ years in the future is $p_{n}$, then the value of that asset now is
\[ \sum_{n=0}^\infty d^n p_n \]
If $p_{n} = p$ is constant, then this reduces to
\[ p \sum_{n=0} d^{n} = \frac{p}{1-d} \]
This idea of a discount rate (and implicitly this formula, and variations of it), have been in use since the fourteenth century, where it was first introduced by Italian merchants (according to Bichler and Nitzan). As the centuries went on, it spread farther and farther, although not everyone really did the math "correctly" (showing that it's only a law in as much as people agree that it is).

In 1907, Irving Fisher proposed that this discounting logic was in fact universal.

> It is evident that not bonds and notes alone, but all securities, imply in their price and their expected returns a rate of interest. There is thus an implicit rate of interest in stocks as well as in bonds. . . . It is, to be sure, often difficult to work out this rate definitely, on account of the elusive element of chance; but it has an existence in all capital. . . . It is not because the orchard is worth $20,000 that the annual crop will be worth $1000, but it is because the annual crop is worth $1000 that the orchard will be worth $20,000. The $20,000 is the discounted value of the expected income of $1000 per annum; and in the process of discounting, a rate of interest of 5 per cent. is implied.

Bichler and Nitzan are really good a picking good quotes from old economists, so I can't resist giving you another one:

> The primitive economy in its choice of enjoyable goods of different epochs of maturity, in its wars for the possession of hunting grounds and pastures, in its slow accumulation of a store of valuable durable tools, weapons, houses, boats, ornaments, flocks and herds, first appropriated from nature, and then carefully guarded and added to by patient effort — in all this and in much else the primitive economy, even though it were quite patriarchal and communistic, without money, without formal trade, without definite arithmetic calculations, was nevertheless *capitalizing*, and therefore embodying in its economic environment a rate of premium and discount as between present and future. (Fetter 1914b: 77, emphasis due to B&N)

After this quote, Bichler and Nitzan quip

> In short, if human beings were indeed made in the image of God, the Almighty must have been a bond trader.

<span style="color:red"> (Illustration of God as a bond trader) </span>

However, despite these enthusiastic embraces of capitalization from the dismal science, the general public were not convinced, and the capitalization formula was not yet embraced. It was not until the dazzling onslaught of complexity in corporate finance that started to unfold in the 1930s and 1940s that the capitalization formula was firmly grasped as a principle with which to evaluate and price assets and make sense of the growing chaos. Later on, risk was incorporated formally into the model, and these modern practices of corporate finance became so firmly entrenched that one would be entirely forgiven if one supposed that they were laws of nature.

For me, this was an interestingly different way of looking at capitalism. Capitalism is typically presented as a system that embraces markets, whereas this presents capitalism as a logic for how to price things in the context of markets. In theory, another polical system could use markets without using the same pricing logic. However, no individual within the current system can change the logic that they use to price the things they sell.

This is also a very different way of thinking about things from "supply and demand."
