---
title: Coends and Integrals
---

# Introduction

Here I was, browsing through twitter, and I came across an innocuous [tweet](https://twitter.com/AlexKontorovich/status/1330175610417721345?s=20) by Alex Kontorovitch.... Or was it?

First of all, a warning. This is more of a "new result" blog post than it is a "explaining something that already exists", so I hate to say it but if you are not familiar with coends or differential forms, the rest of this will be pretty gobbledigookish.

As I assume the reader is familiar with, there's a well-known construction in category theory called an *coend*, which produces an element of $\mathsf{D}$ from a profunctor $P \colon \mathsf{C}^{\mathrm{op}} \times \mathsf{C} \to \mathsf{D}$. The notation for it looks like this

$$ \int^{c \in \mathsf{C}} P(c,c) \in \mathsf{D}$$

It has this notation because it has a lot of properties that are very reminiscent of integrals. Coends (and their dual, ends) are very useful for a lot of constructions in category theory, except for, funnily enough, calculus. Or at least, so I've been told; perhaps the correspondence that I am about to make has already been done.

Anyways, plowing ahead, I am going to do a construction that relates coends and actual integrals, and it may or may not be original, so hold onto your seats folks.

# The Construction

Let $M$ be a manifold. Then for any $k$, define $C_{k}(M)$ to be the $\mathbb{R}$-algebra freely generated by all differentiable maps $\Delta^{k} \to M$, where $\Delta^{k}$ is the $k$ -simplex. As we are familiar with from simplicial homology, this turns into a chain complex, with a "boundary map" $\partial_{k} \colon C_{k}(M) \to C_{k-1}(M)$.

We also have another chain complex, this one coming from de Rham cohomology, and given in degree $k$ by $\Omega^{k}(M)$, the $\mathbb{R}$-algebra of $k$-dimensional differential forms on $M$.

If $\mathbb{N}$ is the poset of natural numbers, seen as a category by adding a unique arrow $m \to n$ when $m \leq n$, then $C_{-}(M)$ is a contravariant functor from $\mathbb{N}$, and $\Omega^{-}(M)$ is a covariant functor from $\mathbb{N}$.

Now, if $\sigma \colon \Delta^{k} \to M$ is a differentiable map, then we can integrate a $k$-form $\omega \in \Omega^{k}(M)$ along it to get

$$ \int_{\sigma(\Delta^{k})} \omega \in \mathbb{R}$$

For notational reasons, I define $\mathrm{int}_{k}(\sigma,\omega)$ to be this integral; from henceforth the integral sign will be reserved for coends. We extend $\mathrm{int}_{k}(-,\omega)$ to be a map $C_{k}(M) \to \mathbb{R}$ using the fact that $C_{k}(M)$ is the free $\mathbb{R}$-algebra on maps $\Delta^{k} \to M$. With a bit of work, one can show that this is a map $\mathrm{int}_{k} \colon C_{k}(M) \otimes \Omega^{k}(M) \to \mathbb{R}$, because $\mathrm{int}_{k} \colon C_{k}(M) \times \Omega^{k}(M) \to \mathbb{R}$ is bilinear.

We can glue together these maps for all $k$ to get a map

$$ \mathrm{int} \colon \coprod_{k \in \mathbb{N}} C_{k}(M) \otimes \Omega^{k}(M) \to \mathbb{R} $$

Now comes the fun part. Stoke's theorem says that $\mathrm{int}_{k}(\partial \sigma, \omega) = \mathrm{int}_{k+1}(\sigma, \delta \omega)$. This precisely satisfies the universal property of the coend! That is, recall that the coend of the profunctor $C_{-}(M) \otimes \Omega^{-}(M)$ is the colimit of

$$ \coprod_{n \leq m} C_{m}(M) \otimes \Omega^{n}(M) \rightrightarrows \coprod_{k} C_{k}(M) \otimes \Omega^{k}(M) $$

where the two maps apply the morphism $n \leq m$ contravariantly to $C_{m}(M)$ (i.e., $\partial^{m - n}$), or covariantly to $\Omega^{n}(M)$ (i.e. $\delta^{m-n}$). As $\delta^{2} = 0$ and $\partial^{2} = 0$, the only interesting case is $m = n+1$, and Stoke's theorem precisely states that in that case, the images of those two maps integrate to the same thing! Therefore, we can extend $\mathrm{int}$ to a $\mathbb{R}$-algebra morphism

$$ \mathrm{int} \colon \int^{k \in \mathbb{N}} C_{k}(M) \otimes \Omega^{k}(M) \to \mathbb{R} $$

What is this strange $\mathbb{R}$-algebra called $\int^{k \in \mathbb{N}} C_{k}(M) \otimes \Omega^{k}(M)$? I have no idea. I don't know if this algebra goes by another name, or is interesting for any reason. But I do believe that this construction is functorial in $M$, so this gives a functor from manifolds to $\mathbb{R}$-algebras, which one might hope preserves things that are important.

Mainly, I'm just happy that coends have any relation to integrals. Also, I wonder if the different properties that coends have (i.e., Fubini's theorem, Hom-functor as Dirac delta) can somehow be brought to bear on this construction.

Send me thoughts about this!
