---
title: Legibility
tweet: true
---

## Legibility in Cartoons

"Can't Stop Conducting" is a classic Tom and Jerry cartoon where Tom is conducting an orchestra, and Jerry is trying to conduct along with him. Tom's pride as a conductor will not allow this, and classic fights ensue.

I want you to watch this right now, and pay attention to how *legible* every single action in this sketch is. Almost every action has some sort of windup, and some sort of predictable consequence. The emotions of the characters are clearly expressed through their faces and body languages, and more than that, the motivations of the characters are clear from the beginning and consistent throughout. Tom wants to be the star of the show, and Jerry wants to be part of the show. 

And most importantly, the action is totally in sync with the music, from the rhythm to the thematic content.

<iframe width="560" height="315" src="https://www.youtube.com/embed/zuws6RCkkoI" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

I wish that people had made me pay attention to the concept of legibility earlier in my life. I used to think that creation was all about *creativity*; all about having *new* ideas that nobody else had ever had before and producing something wacky and original.

But look at that Tom and Jerry sketch. I think that the writers of that Tom and Jerry sketch were *very* creative; coming up with the action sequences and character motivations that fit perfectly with the music is not easy!

That being said, the sketch holds together because of so much that is very recognizable and predictable. The setting is a generic outdoor concert shell. The dress for both are classic orchestral tuxes. Tom's mannerisms as a conductor are very familiar to anyone who has been in an orchestra, from the [little finger waggles](https://youtu.be/zuws6RCkkoI?t=187) telling the violins to play lushly, to the [pushing hands](https://youtu.be/zuws6RCkkoI?t=241), telling the orchestra that even though this is an accelerando, they should speed up *gradually*. And in [one of my favorite moments](https://youtu.be/zuws6RCkkoI?t=225), the conductor *always* has a spare baton.

Even the end, where Tom keeps conducting, not noticing his surroundings while zooming down the highway, is consistent with the logic that has been set up [earlier in the sketch](https://youtu.be/zuws6RCkkoI?t=94), when Jerry doesn't notice that he's been flung across the stage, and keeps conducting, and even [at the very start](https://youtu.be/zuws6RCkkoI?t=58).

I sum this up by saying that the *legibility* of the sketch is the key to its humor. Each of the things that I mentioned contributes to legibility in some way:

- Synchronized music and action makes both the music and the action more legible
- Stock images and gestures help the audience parse the scene into well-known chunks
- Repetition of actions creates a consistent logic (even if the logic is not realistic)
- Clear and simple motivations help the reader understand why things are happening

In this blog post, I aim to investigate this concept of legibility further, and argue that understanding legibility is an important step for becoming a better creator. To this end, I will compare legibility as it applies in a couple domains, and draw some general conclusions for how to pursue legibility.

## Use of Language

One of (in my opinion) the best writers of the decade has very kindly shared with us the [secrets to his success](https://slatestarcodex.com/2016/02/20/writing-advice/). In one of the sections he talks about the use of connecting words.

> I lampshade my flow of ideas with a lot of words like “Also”, “But”, “Nevertheless”, “Relatedly”, and “So” (when I’m feeling pretentious, also “Thus”). These are the words your eighth-grade English teacher told you never to start paragraphs with. Your eighth-grade English teacher was wrong. If you’re writing three paragraphs that are three different pieces of evidence for the same conclusion that you’re going to present afterwards, make damn sure your readers know this. It could be as simple as:
>
>> It’s pretty obvious that X is true, [and]{.underline} we have lots of converging lines of evidence for this. [Some of the best evidence]{.underline} comes from the field of augury. For example:
>>
>>    [First]{.underline}, A
>>
>>    [Second]{.underline}, B
>>
>>    [Third]{.underline}, C
>>
>>    [Now]{.underline}, some people say that not-A, but that’s totally wrong. It only looks like not-A, [because]{.underline} P. [Likewise]{.underline}, [although]{.underline} Q might make it look like not-B, Q can’t be trusted for several other reasons, [for example]{.underline} R. And not-C is too silly to even think about. [So]{.underline} [despite]{.underline} the objections you always hear, the augurical evidence for X is strong.
>>
>>    [Even more]{.underline} evidence comes from the field of haruspicy. [All]{.underline} four major haruspical schools hold X as a major principle. School 1 says X because of D. School 2 says X because of E. School 3 says X because of F. [And]{.underline} school 4 says X because of G. [So although]{.underline} augury and haruspicy disagree on a lot, on the subject of X they are in complete accord.
>
> Notice the underlined words holding up the structure of the argument. Not only is the argument nice and tight, but the role of each part in the whole is telegraphed beforehand. For example, the “now” that comes just after C is saying something like “Take a step back, I’m about to tell you something that might otherwise be controversial, but listen to what I have to say”. And the “likewise” just after P means something like “We just got down talking about not-A because P, here’s another argument with about the same structure”. Before any of the facts are inserted, you already know where they fit into the structure. And you’re able to abstract from the micro-level and get the bigger picture of some fact which is supported by both augury and haruspicy, which was the main point of the argument.

Essentially, these "lampshading" words work to make the flow of ideas *legible*. I think of lampshading words like the "wind-up" to every action in the Tom and Jerry cartoon.

For instance, consider the classic ["run wind-up"](https://youtu.be/zuws6RCkkoI?t=48). You know that Jerry is about to zip across the screen, and also it's clear that Jerry feels like he's late to something and is rushing to catch up, just like when Scott says "Even more", you know that he's about to list some more evidence that's in agreement with the previous paragraph.

I could spend pages talking about other structures in writing that increase legibility, but this post isn't about how to effectively use legibility in every single domain, it's about noticing common threads across domains.

## Music Theory

One of my biggest complaints when I was learning music theory was always that music theory seemed to always be teaching you about *how* a piece was put together, and never why.

But now I understand more about exactly what the point of music theory is. By identifying structures common among music in a given style, one can understand how to effectively use musical cliches to convey a certain tone. For instance, the James Bond theme famously ends with a minor major seventh chord (see: [James Bond](https://youtu.be/U9FzgsF2T-s?t=160), [explanation](https://www.youtube.com/watch?v=IGfipzDfkb8)). From that cultural association, you can bring out a certain spy-like feel in something that you are writing by using a minor-major seventh. This is only partly because of the intrinsic sound of the minor-major seventh; audiences have an association with the minor-major seventh that is purely cultural (even if they might not realize it).

Another example of legibility in music theory is the ballet Petrushka, by Stravinsky. If you just listen to the music of Petrushka, it makes very little sense. But when you see it [actually staged](https://www.youtube.com/watch?v=XvXlFKvpoOg), the movements of the dancers make it (more) clear what's going on in the music. [One part](https://youtu.be/XvXlFKvpoOg?t=149) of the music that can be particularly confusing to listen to in the introduction is when there are two themes playing at once. When you see the ballet you see that this is because there are two competing music box ladies. Understanding the (vaguely specified) plot of the ballet brings a narrative structure to the music that makes it more legible.

The key is that even though Petrushka doesn't have a traditional classical structure like a Mozart piece, it holds together and makes sense through the narrative structure, and the use of repetitive and recognizable themes for different characters. If Petrushka simply broke classical rules without having some substitute for creating legibility, it would not be successful at all.

I think that this is a general principle for new art. You can break as many rules as you like, as long as you come up with new rules to replace them, and continue to keep your art very legible.

## Design

I hope at this point I've conveyed why I think legibility is important, but for the sake of repetition (a key part of legibility), I'm going to give another example.

Taking legibility literally, it is most directly applicable in graphic design. You can see this in Matthew Butterick's [Practical Typography](https://practicaltypography.com/). First of all, as an object of graphic design, the design of that webpage is totally clean. Immediately you can see what is going on: it's a book and this is the table of contents. There is also a tasteful grid structure that more efficiently uses the space of the table of contents.

But secondly, the book starts by talking about why "the programmer, the scientist, the lawyer" should care about typography.

> I’m not here to tell you that typography is more important than the substance of your writing. It’s not.
> 
> But typography can enhance your writing. Typography can create a better first impression. Typography can reinforce your key points. Typography can extend reader attention. When you ignore typography, you’re ignoring an opportunity to improve the effectiveness of your writing.
> 
> And isn’t that why you write at all? To have an effect on readers? To move them, to persuade them, to spur them to action?

I think that if you replaced every instance of "typography" in that block quote with "legibility", each point would still hold.

## Legibility More Generally

At this point, I have finished making my main argument about the importance of legibility in creative arts. So now I'm going to make some unwarranted speculations on legibility outside of art, and also on mathematical interpretation of legibility.

In James C Scott's book [Seeing Like a State](https://yalebooks.yale.edu/book/9780300078152/seeing-state) ([book review/summary](https://slatestarcodex.com/2017/03/16/book-review-seeing-like-a-state/)), a central theme is that the legibility of a society is key to the ability of the state to govern that society.

For example, in medieval France, where most men had one of six first names and no last names, it was very hard for tax collectors to figure out who had paid taxes. For people in the village, they could differentiate "Jaque the smith" and "Jaque who lives under the hill" and "Jaque the baker", but these sort of loose names were impossible to keep track of for the state, which needed identifiers that were valid in a larger scope. Last names were invented to make the population more legibile to the state, and this in turn enabled the state to tax more efficiently.

This sort of thing appears all throughout the book. However, I'm not going to try and analyze it at the moment; I am just bringing up an interesting connection.

Finally, I have a sneaking suspicion that legibility has something to do with information theory. In art, legibility often comes down to repetition and the use of tropes. I feel like this should have something to do with the efficiency of encoding schemes, and making the informational content of a piece clearly and redundantly expressed in an encoding scheme that is easy on the brain. But again, I'm just bringing this up as a connection; to probe this more thoroughly is a whole line of research!

And that's all for now! Tweet at me or blog at me with any comments (instructions down below).
