---
title: Wave Particle Duality and the Grothendieck Construction
---

## Discrete Wave/Particle Duality

Traditionally, wave particle duality is considered a part of quantum mechanics. However, a similar phenomenum can show up in classical or probabilistic settings. In this blog post, we investigate this, and how it is related to the Grothendieck construction, which is a construction from category theory.

Imagine that you have $m$ boxes with balls in them. There are two ways of representing this mathematically. The first is by having a function from $\{1,\ldots,m\} \to \mathbb{N}$, which sends the label of each box to the number of balls in that box. The second is by making a set of balls $B$ and then having a function $B \to \{1,\ldots,m\}$, which sends each ball to the box that it lives in.

We call the first way of representing the situation the "wave" representation. Instead of keeping track of individual balls, we have a "distribution" of balls across boxes. We call the second way the "particle" representation, where we keep track of individual balls.

What's the difference? One answer is that the particle representation has more symmetries. That is, there are many different assignments of boxes to $B$ that end up with the same number of balls in each box.

When we do probability theory, this is important, because the prior probability distribution for a variable $Y$ that ranges over a finite set that we know absolutely nothing about is uniform. But if $Y = f(X)$ for another variable $X$, then an assignment of a uniform probability distribution to $X$ often produces a non-uniform probability distribution for $Y$. Specifically, if $Y = y$ can happen "in more ways" than $Y = y'$, we give it a higher probability. An example of this is that we assign a higher probability to 5 heads, 5 tails, than we do to 2 heads, 8 tails. So if the particle representation shows certain scenarios happening "in more ways" than the wave representation, then choosing between particle representation and wave representation changes the priors we assign!

Another difference is that if we now have a dynamical system of balls and boxes, then the particle representation can detect the difference between the following scenarios:

1. We move a ball from box 1 to box 2, and a ball from box 2 to box 1.
2. We do nothing.

In both scenarios, the total number of balls in each box stays the same, so the wave representation detects no change. But in the particle representation, we have changed the assignments of boxes to balls.

A system in which the wave representation is constant, but the particle representation is not is often said to be in [dynamic equilibrium](https://en.wikipedia.org/wiki/Dynamic_equilibrium).

Now that we have the basic setup, we will discuss two logically distinct "branches". The first branch has to do with extensions of the basic setup to statistical mechanics. The second branch has to do with the category theory of the basic setup.

## Wave/Particle Duality in Statistical Mechanics

I have some understanding that what I am about to discuss often goes under the name of "field theory", but I am not at all an expert on field theory; what follows are some concepts that have likely trickled down to me and slowly been repackaged into my own understanding. That is to say, there are likely textbooks that cover this in much better detail, but I don't know which ones to cite and don't particularly feel like doing a literature review for a blog post.

Anyways, we can "soup up" the previous wave particle duality to cover probabilistic waves/particles in the following way.

The "particle" point of view is that each ball $b \in B$ is assigned a random variable $X_{b} \in \{1,\ldots,m\}$ over boxes. The "wave" point of view is that each box $i$ is assigned a random variable $N_{i} \in \mathbb{N}$ over the number of balls in that box.

Note that I said "random variable" instead of "probability distribution"; this is because the different variables might have non-trivial correlations!

We can further extend this to the situation where the balls are distributed in space, i.e. in $\mathbb{R}^{n}$. The particle point of view would be again to assign a variable $X_{b}$ taking values in $\mathbb{R}^{n}$ to each particle, and the wave point of view would be to assign a variable $N_{U}$ taking values in $\mathbb{N}$ to each open set $U \subset \mathbb{R}^{n}$, satisfying certain laws such as $N_{U} \leq N_{V}$ whenever $U \subset V$ (because the particles in $U$ necessarily are also in $V$).

These two points of view diverge even more significantly from before, because in the particle point of view the number of particles is fixed, but in the wave point of view it might vary. This could be remedied by first having a distribution over the number of particles, and then having a distribution on each particle that was conditional on the overall number of particles.

With this adjustment having been made, the essential differences between the two situations are quite similar to the classical case, and we will not discuss them more here to keep this post short. The main point that I wanted to make was in fact that although we normally think of waves as continuous, like the probability distributions are here, the wave particle duality in the continuous or discrete setup has similar characteristics.

## The Grothendieck Construction

The [Grothendieck construction](https://ncatlab.org/nlab/show/Grothendieck+construction) is a very general idea in category theory; in this section we consider just a specific instance of it and show how it formalizes wave/particle duality. In this section, I assume that you know what a category is, what a functor is, and what a natural transformation is, but other concepts I will give definitions or references for.

:::{.rmenv title="Definition"}
Let $\mathbb{F}$ be the category where the objects are natural numbers, and a morphism from $n$ to $m$ is a function from $\{1,\ldots,n\} \to \{1,\ldots,m\}$.
:::

The particle point of view is expressed as the *slice category* $\mathbb{F}/m$, defined below.

:::{.rmenv title="Definition"}
Let $\mathsf{C}$ be a category, and fix an object $x \in \mathsf{C}$. Then the category $\mathsf{C}/x$, called **the slice category of $\mathsf{C}$ over $x$** is defined in the following way.

- The objects of $\mathsf{C}/x$ are pairs $(y \in \mathsf{C}, f \colon y \to x)$
- a morphism from $(y,f)$ to $(z,g)$ is a morphism $h \colon y \to z$ such that $f = g \circ h$, or in other words the following triangle commutes: <br>

<!-- https://q.uiver.app/?q=WzAsMyxbMCwwLCJ5Il0sWzIsMCwieiJdLFsxLDEsIngiXSxbMCwxLCJoIl0sWzAsMiwiZiIsMl0sWzEsMiwiZyJdXQ== -->
<iframe class="quiver-embed" src="https://q.uiver.app/?q=WzAsMyxbMCwwLCJ5Il0sWzIsMCwieiJdLFsxLDEsIngiXSxbMCwxLCJoIl0sWzAsMiwiZiIsMl0sWzEsMiwiZyJdXQ==&embed" width="432" height="304" style="border-radius: 8px; border: none;"></iframe>
:::

An object of $\mathbb{F}/m$ is a natural number $N$ along with a morphism $N \to m$, which is a function $\{1,\ldots,N\} \to \{1,\ldots,m\}$; one can see that this is precisely the particle point of view!

The wave point of view is expressed as the *product category* $\mathbb{F}^{m}$, defined below.^[Note: this could also be seen as the category of functors from the discrete category with objects $\{1,\ldots,m\}$ to $\mathbb{F}$, but we don't need this level of generality here.]

:::{.rmenv title="Definition"}
Let $\mathsf{C}$ be a category, and $m$ be a natural number. Then the **product category** $\mathsf{C}^{m}$ is defined in the following way.

- The objects of $\mathsf{C}^{m}$ are functions $p \colon \{1,\ldots,m\} \to \mathsf{C}_0$, where $\mathsf{C}_{0}$ is the collection of objects of $\mathsf{C}$
- A morphism from $p$ to $q$ consists of a morphism $\alpha_{i} \colon p(i) \to q(i)$ for every $i \in \{1,\ldots,m\}$.
:::

An object of $\mathbb{F}^{m}$ is a function from $\{1,\ldots,m\}$ to $\mathbb{N}$, so it is precisely the wave point of view!

The Grothendieck construction is an *equivalence of categories* between $\mathbb{F}^{m}$ and $\mathbb{F}/m$. Informally speaking this is saying that these categories *can be treated equivalently* as long as you stick to using them in a category theoretic way. I.e., clearly these are different categories. But as long as you stick to operations which are "defined categorically" (whatever that means), you can't tell the difference between these two categories!

To fully define and prove this equivalence of categories would take more time than I want to spend here, but I will sketch the construction.

:::{.rmenv title="Definition"}
Let $\mathsf{C}$ and $\mathsf{D}$ be categories. Then an **equivalence** between them consists of:

- a functor $F \colon \mathsf{C} \to \mathsf{D}$
- a functor $G \colon \mathsf{D} \to \mathsf{C}$
- a natural isomorphism $\alpha \colon G \circ F \cong 1_{C}$
- a natural isomorphism $\beta \colon F \circ G \cong 1_{D}$
:::

We now sketch an equivalence between $\mathbb{F}/m$ and $\mathbb{F}^{m}$. Define a functor $F \colon \mathbb{F}/m \to \mathbb{F}^{m}$ on objects by sending an object $p \colon N \to m$ to the function $f \colon m \to \mathbb{N}$ sending $i \in \{1,\ldots,m\}$ to the size of the preimage of $i$ under $p$, i.e. $|p^{-1}(i)|$.

It is a little tricky to define $F$ on morphisms, but the basic idea is the following.

Recall that a morphism in $\mathbb{F}/m$ from $p \colon N \to m$ to $q \colon M \to m$ is a morphism $r \colon N \to M$ such that $p = q \circ r$. This means that for all $i \in \{1,\ldots,N\}$, $q(r(i)) = p(i)$. Thus, for any $b \in \{1,\ldots,m\}$, $r$ sends the $p$-balls in $b$ to the $q$-balls in $b$, and so restricts to a function $r_{b}$ from $p^{-1}(b)$ to $q^{-1}(b)$.

Now, we have a canonical isomorphism between $p^{-1}(b)$ and $\{1,\ldots,|p^{-1}(b)|\}$ given simply by ordering the balls in $p^{-1}(b)$ by their numbers (as $p^{-1}(b) \subset \{1,\ldots,N\}$), and similarly we have a canonical isomorphism between $q^{-1}(b)$ and $\{1,\ldots,|q^{-1}(b)|\}$. This means that we can take our function $r_{b}$ and treat it as a morphism $F(p)(b) \to F(q)(b)$ in $\mathbb{F}$, and if we assign $F(r)_{b} = r_{b}$ for every $b \in \{1,\ldots,m\}$, then $F(r)$ is a morphism in $\mathbb{F}^{m}$, as required!

Basically, all we are doing here is splitting up a "box-respecting" function between balls to a function for each box that is just defined on the balls in that box.

To go the other way from $\mathbb{F}^{m}$ to $\mathbb{F}/m$, we define a functor $G$ in the following way.

On objects, send a function $f \colon \{1,\ldots,m\} \to \mathbb{N}$ to the natural number $N = \sum_{i=1}^{m} f(i)$, along with the function $p \colon \{1,\ldots,N\} \to \{1,\ldots,m\}$ which sends $\{1,\ldots,f(1)\}$ to $1$, $\{f(1) + 1,\ldots,f(1) + f(2)\}$ to $2$, and so on.

Then on morphisms, we essentially "invert" the procedure we did earlier. Given a collection of functions, one for each box, we "glue them together" to get a function on all of the balls. Writing out the precise details of this is left as an exercise to the reader.

The natural isomorphisms come essentially from the intuitive notion that breaking up the balls by box and then putting them back together ends up with the same number of balls you had from the beginning! The only difference is that you now have the balls ordered by box, so you need to have a permutation of $\{1,\ldots,N\}$ to record this, and so $G \circ F$ is not the **identity functor** on $\mathbb{F}/m$, just naturally isomorphic to it.

And conversely, putting all the balls together and then splitting them up again also leaves you with the same balls in the same boxes.

## Concluding thoughts

What have we learned from analogizing wave/particle duality to the Grothendieck construction? Well, first of all, we have learned that the apparent differences between the wave viewpoint and the particle viewpoint seem to disappear when you add the right morphisms! This implies that the "counting" problems that we had at the beginning might be solved by a more refined theory of counting, such as [groupoid cardinality](https://ncatlab.org/nlab/show/groupoid+cardinality). Essentially, groupoid cardinality allows you to count things in a way that takes symmetries into account. I have not yet fully worked out the implications of groupoid cardinality for putting uniform priors on balls in boxes, but I think that when taken seriously, groupoid cardinality should give the same prior for the wave and particle perspective!

Secondly, we said that the other difference between waves and particles had to do with dynamics, when we consider balls that change boxes. Now, note that in the setup for the Grothendieck construction, the morphisms we chose did not allow balls to change boxes. To me, this implies that perhaps there is a more general construction where we *do* allow balls to change boxes; i.e. a slice category where the triangle does not have to commute! I'm not sure what the analogous wave-viewpoint is categorically, and I'm not sure what the implication is for higher versions of the Grothendieck construction; I would be happy to hear from anyone who has an answer to this!

And that's all for 2022! See you in 2023!
