---
title: Malthus Was Optimistic
---

Note: I'm not going to be making airtight arguments here. There are plenty of simplifications that I am making that don't necessarily hold. However, I think that the conclusion is still valuable, and with a lot of work can be put on a more solid footing, and in any case is something that we have to confront and think about.

## A Malthusian Primer

For those who are not familiar with Thomas Malthus, he was an early economist who predicted that technological gains would lead to a larger population that struggled just as much to sustain itself as previous generations. As we became more efficient at agriculture, we would birth that many new mouths to feed, and so we would eventually reach the same level of conflict and poverty even with more resources. The faster we learned to run, the faster the treadmill would spin.

One way of modelling this mathematically is with the logistic growth model. You will be familiar with this if you have read my posts on Petri nets, but for those who have not, I will summarize the logistic model here. Essentially, the logistic growth model assumes that there are two processes going on.

1. Birth. Over a given span of time, there is a fixed probability that a given person will give birth to another person (we assume asexual reproduction -- it turns out not to matter too much whether we are looking at sexual or asexual reproduction)
2. Conflict. Over a given span of time, there is a fixed probability that a given pair of people will come into conflict over something, and one of them will die. This models competition over resources.

We assume that the probability of conflict for any two given people is very low. Therefore, the amount of conflict will be quite small when the population is low, and the behavior of this model will be dominated by the birth process. However, as the population grows, conflict becomes more and more likely until finally it balances out growth and the population becomes stable, because $x^2$ grows faster than $x$.

You can play with this model [here](https://owenlynch.org/static/ez-petri/#kpOvTG9naXN0aWMgR3Jvd3RokpOlQmlydGiRAZECk6hDb25mbGljdJECkQGRqlBvcHVsYXRpb26Vkco9I9cKkso_rhR7yj7Cj1zKQSAAAMpAoAAAykCgAAA=).

If we project Malthus' arguments onto the logistic growth model, we can say that technological progress or civilizational progress increases the birth rate and decreases the conflict rate by opening up more resources. You can see for yourself what this does in the model above; it just changes the eventual steady state population. In other words, the population will rise to the level at which there is enough conflict to keep it stable there. No matter how much we decrease conflict or make our lives easier, rising populations will increase conflict until it balances birth.

This is a pretty bleak worldview. We are used to thinking that advances in technology will make our life easier, but according to Malthus, the only reason that we have easier lives than our ancestors is because the rate of technological/societal change has temporarily outpaced population growth. Once we slow down the rate of invention and policy innovation, we will be right back to square one. Just stay at the same level of leisure, we have to run faster and faster. The point is, what matters is not the level of technology, but the rate of technological development, and specifically whether or not it is currently outpacing population growth.

## But Wait! It's Worse!

However, the conflict process only models constraints to growth based on competition over renewable resources. You might be thinking about solar energy when I say renewable resources, but a better example would be conflict over land. Land is renewable because it doesn't go away. However, what if we add a *non-renewable* resource to the model, such as oil? A simple way to do this would be to require the resource in the birth process, which you can see [here](https://owenlynch.org/static/ez-petri/#kpO0Tm9uLXJlbmV3YWJsZSBHcm93dGiSk6VCaXJ0aJIBAZIAApOoQ29uZmxpY3SSAAKSAAGSo09pbKZQZW9wbGWVkspAI9cKyj0j1wqSykAAAADKQIHrhcpBIAAAykCgAADKQKAAAA==). In this model, there is an initial spike and then a die off.

Nothing I'm saying here is particularly new. I am still learning about some of the math behind stochastic models that allow you to calculate "mean extinction times", and I hope to talk about this more in a future post, but the math doesn't tell us anything that common sense can't. In a model where growth is mediated by a non-renewable resource, we are necessarily setting ourselves up for a massive drop in population. And to be clear, this is not old people aging out and young people not replacing them. This is a large population suddenly not having anything close to the amount of resources necessary to sustain itself, and tearing itself apart by fighting over them.

In all of human history, we have managed to transition to new non-renewable resources when we run out of old ones, so we have lived in a Malthusian regime where the conflict has mainly been over renewable resources (i.e. land) or semi-renewable resources (i.e. oil wells---oil wells pump oil for a while, they are not single-use). And the faster we have advanced technology, the more thoroughly we have managed to escape the Malthusian conclusion. All the data points to growth lifting the human race up and up, ever forward to higher and higher standards of living.

One acknowledgement of this is what Robin Hanson calls ["The Dream Time"](http://www.overcomingbias.com/2009/09/this-is-the-dream-time.html). We live in a time in which the rate of discovery has outpaced the rate of population growth. Consequently, we have been able to live above subsistence and indulge our passions for math, art, memes, fancy cars, ironic mascot costumes, and whatever else we choose. Robin Hanson imagines that in a while, our descendants will be back to subsistence level as technological progress finally slows and population growth catches up.

Certainly, this has happened at a micro-level when technological growth stalls temporarily. But, just like in a Road Runner cartoon, the truth about the ground under our feet can change drastically in a short amount of time. When dealing with population at the scale of the 21st century, the Malthusian model no longer holds because we are making a sizable dent in non-renewable planetary resources. I think people have a very acute understanding of the need for sustainability, but I still hear people talk about "sustainable growth". What is missing from the Overton window is an idea that we may have already run off of the cliff, and we need to turn around, flap our arms, and desparately grab a tree branch. People talk about environmental policy shrinking the economy as if it is a problem, while in fact environmental policy *should* shrink the economy. We need to try and shrink GDP, and lower the standard of living to a more respectable sustainable level. "Sustainable growth" is an oxymoron.

![](http://dcewboipbvgi2.cloudfront.net/sites/default/files/styles/article_hero_image/public/articles/11152012_WileECoyote_article.jpg?itok=uoq7Z9RX){width=70%}

Again, this idea is not original to me, but I hope I am packaging it in a way that may make more sense to readers of this blog, and I hope that I am spreading something that is not yet common knowledge.

## What Do We Do?

Obviously, politicians cannot run for office on a platform of shrinking the economy right now. Not only do many people think this is crazy and harmful, but also many people who might agree with it will not vote for them because they (rightly) assume that nobody else will vote for them. However, history provides us with a proven path for ideas like this. The most influential society that you have never heard of is the Mont Pelerin society. As usual, Slate Star Codex [does the best job](https://slatestarcodex.com/2019/03/18/book-review-inventing-the-future/) summarizing their goals.

> Friedrich Hayek founded the Mont Pelerin Society (named after the site of its first meeting) to promote neoliberalism – here meaning the sort of small-ish government free market thinking common in economics today. At first they were just a few fringe thinkers with no power. But they developed a long-term strategy to change that. Vaughn, S&W, and others sum up the basic points as:
>
> 1. Foster intellectual talent
>
> 2. Seek long-term academic influence. Getting your members professorships won’t feel as exciting and tangible as reshaping policy immediately. Get the professorships anyway.
>
> 3. Push a utopian vision (in the case of the neoliberals, one of freedom and prosperity), along with practical first steps within the Overton Window (eg deregulating the airline industry).
>
> 4. Be prepared to step in as saviors when a crisis arrives. Milton Friedman:
>
>> There is enormous inertia---a tyranny of the status quo---in private and especially governmental arrangements. Only a crisis---actual or perceived---produces real change. When that crisis occurs, the actions that are taken depend on the ideas that are lying around. That, I believe, is our basic function: to develop alternatives to existing policies, to keep them alive and available until the politically impossible becomes politically inevitable.
>
> The neoliberals spent the 1940s through the 1970s slowly moving through steps 1 – 3. They gathered a stable of friendly academics, journalists, politicians, and (especially) think tanks, sometimes by converting people in positions of power, other times by putting their own loyalists into positions, and especially by founding their own organizations. When the stagflation crisis of the 1970s struck, they had marshalled a strong case as the alternative to the Keynesian system that had produced the crisis. Politicians – especially Ronald Reagan and Margaret Thatcher – agreed to implement their policies, and the rest is history.

Another good example of something like this is intersectional feminism. Intersectionality was first coined in an [essay written in 1991](https://www.jstor.org/stable/1229039?seq=1), but the roots of intersectionality go back to the 70s and 80s when black feminists started to question the historical exclusion of African-Americans from feminist movements. However, it was not until the early teens (in my subjective opinion) that the modern social justice movement really kicked off. I don't know if there was ever a Mont Pelerin-type society for intersectionality, but if there was they did a fantastic job; the ideas championed by intersectional feminism are now front and center in modern discourse.

Fortunately, this sort of movement has already sort of started: [Degrowth](degrowth.org). I don't know if Degrowth can be as influential as the Mont Pelerin society, but it looks like they are doing good work in getting members into academia, and developing the necessary intellectual infrastructure for the idea. Another project in this space is the [Azimuth project](https://www.azimuthproject.org/azimuth/show/HomePage) which compiles resources for understanding climate change. But I think there is much much more that can be done. Venkatesh Rao [imagines](https://www.theatlantic.com/science/archive/2015/10/why-only-a-technocratic-revolution-can-win-the-climate-change-war/410377/) a war on climate change waged by technocratic regulators. I think he makes the right point in that expecting local-scale change to work is not feasible for a problem of this scale. But he neglects the fact that building up the climate war bureaucracy is not a primitive action. The military was capable of waging World War II because it already existed, and because "declare war" was a course of action within the Overton window of the society. For all of human history we have been waging war in one way or another, and the public and elites have an idea of how it goes. There is no such common understanding for what the shape of a war on climate change would look like.

To build such an understanding, it is imperative that there is an *intellectual* movement first, like the Mont Pelerin society or intersectional feminism. Of course, biologists, ecologists and climate scientists are already working on the science of climate change, but I think the political and economic side is underdeveloped. We can't treat climate change as just a technological and ecological problem; we need to change our entire way of life to not be focused on growth.

The important thing that I want to emphasize is that before this can be a political proposal, it needs to have a strong intellectual backing and needs to have broad mindshare among academics. You may think that it is hopeless to get this implemented, however the examples of intersectional feminism and neoliberalism show that there *is* a pathway to mainstream acceptance. And in fact, at this stage of development for degrowth, you personally can make a difference to its long term prospects.

For instance, I would like to see policy proposals that would shrink the economy while minimizing human suffering. I think that economics has a lot of ties to neoliberal growth politics, but there is much more to the subject than GDP maximization. In an ideal world, we would change political systems, but I think revolution is a fundamentally bad idea, so until then I think that people should look into how, for instance, the Federal Reserve can fight climate change by deliberately shrinking the economy.

I would like to see journalists giving the kind of coverage to scaling down things and making them smaller as they do to scaling up things and making things larger. See: [Low Tech Magazine](https://www.lowtechmagazine.com/). This is not actually too controversial; people love stories about cute low-tech clever solutions that make big tech companies look stupid.

I would like to see fiction writers imagining societies built around rebuilding ecosystems---"terraforming" Earth---because soon Earth will be like an alien planet. I think that rewilding built spaces is a huge idea, and it should get more mindshare in our creative consciousness.

Another economic topic that I would like to see work on is how to incentivize not consuming, and how to incentivize companies to produce long-lasting products that don't need to be replaced every 2 years. The point is, you can't blame companies for following market incentives, or trust companies to work against their own self-interest, you need to change the incentives.

## The Big Picture

One thing that is always funny to me as a mathematician is the use of the word "theory" in the humanities. If somebody says that something has a lot of "theory", what they mean is that it has a lot of critical theory. Critical theory has so much mindshare that it has stolen an entire word from the English language. When I talk about mindshare for degrowth economics, that is what I mean. We are now hyper-conscious of assumptions about race and gender; I think we should also be hyper-conscious of assumptions about growth and sustainability.

But of course, I can't just wave a magical wand and make this happen. However, what I can do is this. Remember how I mentioned Azimuth? Well, I am starting a reading group for Azimuth at Brown. We will read about topics related to climate engineering and climate policy, and discuss them to better understand the tradeoffs and benefits. We won't get anything concrete done and will make no attempt to affect policy. Maybe we will edit the Azimuth wiki. There will be a substantial time commitment, for work outside of the meeting and for the meeting itself, and it probably won't be very fun. But, I will provide a home-cooked, vegetarian, sustainably sourced dinner.

If you are concerned about climate change, and you have the skillset to bring Degrowth ideas into greater mindshare in your field, then I believe that joining this reading group and becoming educated about others' work in this space is a high-impact choice. However, in my experience, people love to join things and hate to stay, so I'm going to do a bit of gatekeeping. If you are seriously interested in the reading group (and are in the Providence area), please email me a paragraph about you and why you are interested. My email is "root at this site". I will respond to your email, and add you to the list that I will email to announce the first meeting.
